@@ -113,7 +113,7 @@ KGameRenderer* Kolf::renderer()
 Tagaro::Board* Kolf::findBoard(QGraphicsItem* item_)
 {
 	//This returns the toplevel board instance in which the given parent resides.
-	return item_ ? dynamic_cast<Tagaro::Board*>(item_->topLevelItem()) : 0;
+	return item_ ? dynamic_cast<Tagaro::Board*>(item_->topLevelItem()) : nullptr;
 }
 
 b2World* Kolf::world()
@@ -464,7 +464,7 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 
 	regAdv = false;
 	curHole = 0; // will get ++'d
-	cfg = 0;
+	cfg = nullptr;
 	setFilename(filename);
 	this->players = players;
 	curPlayer = players->end();
@@ -490,7 +490,7 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 	m_ignoreEvents = false;
 	highestHole = 0;
 	recalcHighestHole = false;
-	banner = 0;
+	banner = nullptr;
 
 	holeInfo.setGame(this);
 	holeInfo.setAuthor(i18n("Course Author"));
@@ -653,13 +653,13 @@ void KolfGame::startFirstHole(int hole)
 		for (; scoreboardHoles < curHole; ++scoreboardHoles)
 		{
 			cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
-			emit newHole(cfgGroup.readEntry("par", 3));
+			Q_EMIT newHole(cfgGroup.readEntry("par", 3));
 		}
 
 		// lets load all of the scores from saved game if there are any
 		for (int hole = 1; hole <= curHole; ++hole)
 			for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
-				emit scoreChanged((*it).id(), hole, (*it).score(hole));
+				Q_EMIT scoreChanged((*it).id(), hole, (*it).score(hole));
 	}
 
 	curHole = hole - 1;
@@ -680,9 +680,8 @@ void KolfGame::setFilename(const QString &filename)
 
 KolfGame::~KolfGame()
 {
-	QList<QGraphicsItem*> itemsCopy(m_topLevelQItems); //this list will be modified soon, so take a copy
-	foreach (QGraphicsItem* item, itemsCopy)
-	{
+	const QList<QGraphicsItem*> itemsCopy(m_topLevelQItems); //this list will be modified soon, so take a copy
+	for (QGraphicsItem* item : itemsCopy) {
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(item);
 		delete citem;
 	}
@@ -693,7 +692,7 @@ KolfGame::~KolfGame()
 void KolfGame::setModified(bool mod)
 {
 	modified = mod;
-	emit modifiedChanged(mod);
+	Q_EMIT modifiedChanged(mod);
 }
 
 void KolfGame::pause()
@@ -753,7 +752,7 @@ void KolfGame::handleMousePressEvent(QMouseEvent *e)
 		//at this point, QGV::mousePressEvent and thus the interaction
 		//with overlays has already been done; we therefore know that
 		//the user has clicked into free space
-		setSelectedItem(0);
+		setSelectedItem(nullptr);
 		return;
 	}
 	else
@@ -854,7 +853,7 @@ void KolfGame::handleMouseReleaseEvent(QMouseEvent *e)
 
 	if (editing)
 	{
-		emit newStatusText(QString());
+		Q_EMIT newStatusText(QString());
 	}
 
 	if (m_ignoreEvents)
@@ -922,13 +921,12 @@ void KolfGame::setShowInfo(bool yes)
 {
 	m_showInfo = yes;
 	QList<QGraphicsItem*> infoItems;
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 			infoItems << citem->infoItems();
 	}
-	foreach (QGraphicsItem* qitem, infoItems)
+	for (QGraphicsItem* qitem : qAsConst(infoItems))
 		qitem->setVisible(m_showInfo);
 }
 
@@ -998,7 +996,7 @@ void KolfGame::keyReleaseEvent(QKeyEvent *e)
 				m_topLevelQItems.removeAll(item);
 				m_moveableQItems.removeAll(item);
 				delete citem;
-				setSelectedItem(0);
+				setSelectedItem(nullptr);
 
 				setModified(true);
 			}
@@ -1082,7 +1080,7 @@ void KolfGame::timeout()
 
 	if (curState == Holed && inPlay)
 	{
-		emit inPlayEnd();
+		Q_EMIT inPlayEnd();
 
 		int curScore = (*curPlayer).score(curHole);
 		if (!dontAddStroke)
@@ -1106,7 +1104,7 @@ void KolfGame::timeout()
 			if (curHole > 0 && !dontAddStroke)
 			{
 				(*curPlayer).addStrokeToHole(curHole);
-				emit scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
+				Q_EMIT scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
 			}
 			QTimer::singleShot(600, this, &KolfGame::holeDone);
 		}
@@ -1317,8 +1315,7 @@ void KolfGame::autoSaveTimeout()
 void KolfGame::recreateStateList()
 {
 	savedState.clear();
-	foreach (QGraphicsItem* item, m_topLevelQItems)
-	{
+	for (QGraphicsItem* item : qAsConst(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(item)) continue; //see below
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(item);
 		if (citem)
@@ -1343,8 +1340,7 @@ void KolfGame::undoShot()
 
 void KolfGame::loadStateList()
 {
-	foreach (QGraphicsItem* item, m_topLevelQItems)
-	{
+	for (QGraphicsItem* item : qAsConst(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(item)) continue; //see below
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(item);
 		if (citem)
@@ -1368,14 +1364,14 @@ void KolfGame::loadStateList()
 			player.ball()->setVisible(!info.beginningOfHole);
 		player.setScoreForHole(info.score, curHole);
 		player.ball()->setState(info.state);
-		emit scoreChanged(info.id, curHole, info.score);
+		Q_EMIT scoreChanged(info.id, curHole, info.score);
 	}
 }
 
 void KolfGame::shotDone()
 {
 	inPlay = false;
-	emit inPlayEnd();
+	Q_EMIT inPlayEnd();
 	setFocus();
 
 	Ball *ball = (*curPlayer).ball();
@@ -1403,7 +1399,7 @@ void KolfGame::shotDone()
 				(*it).addStrokeToHole(curHole);
 
 			// emit that we have a new stroke count
-			emit scoreChanged((*it).id(), curHole, (*it).score(curHole));
+			Q_EMIT scoreChanged((*it).id(), curHole, (*it).score(curHole));
 		}
 		(*it).ball()->setAddStroke(0);
 	}
@@ -1477,7 +1473,7 @@ void KolfGame::shotDone()
 	}
 
 	// emit again
-	emit scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
+	Q_EMIT scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
 
 	if(ball->curState() == Rolling) {
 		inPlay = true; 
@@ -1521,7 +1517,7 @@ void KolfGame::shotDone()
 	}
 	while ((*curPlayer).ball()->curState() == Holed);
 
-	emit newPlayersTurn(&(*curPlayer));
+	Q_EMIT newPlayersTurn(&(*curPlayer));
 
 	(*curPlayer).ball()->setVisible(true);
 
@@ -1535,21 +1531,20 @@ void KolfGame::shotDone()
 
 void KolfGame::emitMax()
 {
-	emit maxStrokesReached(playerWhoMaxed);
+	Q_EMIT maxStrokesReached(playerWhoMaxed);
 }
 
 void KolfGame::startBall(const Vector &velocity)
 {
 	playSound(Sound::Hit);
-	emit inPlayStart();
+	Q_EMIT inPlayStart();
 	putter->setVisible(false);
 
 	(*curPlayer).ball()->setState(Rolling);
 	(*curPlayer).ball()->setVelocity(velocity);
 	(*curPlayer).ball()->shotStarted();
 
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 			citem->shotStarted();
@@ -1636,7 +1631,7 @@ void KolfGame::startNextHole()
 
 	int oldCurHole = curHole;
 	curHole++;
-	emit currentHole(curHole);
+	Q_EMIT currentHole(curHole);
 
 	if (reset)
 	{
@@ -1702,7 +1697,7 @@ void KolfGame::startNextHole()
 		(*it).ball()->setVisible(false);
 	}
 
-	emit newPlayersTurn(&(*curPlayer));
+	Q_EMIT newPlayersTurn(&(*curPlayer));
 
 	if (reset)
 		openFile();
@@ -1732,7 +1727,7 @@ void KolfGame::startNextHole()
 		for (; scoreboardHoles < curHole; ++scoreboardHoles)
 		{
 			cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
-			emit newHole(cfgGroup.readEntry("par", 3));
+			Q_EMIT newHole(cfgGroup.readEntry("par", 3));
 		}
 
 		resetHoleScores();
@@ -1764,8 +1759,8 @@ void KolfGame::showInfoDlg(bool addDontShowAgain)
 void KolfGame::openFile()
 {
 	QList<QGraphicsItem*> newTopLevelQItems;
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	const auto currentTopLevelQItems = m_topLevelQItems;
+	for (QGraphicsItem* qitem : currentTopLevelQItems) {
 		if (dynamic_cast<Ball*>(qitem))
 		{
 			//do not delete balls
@@ -1780,7 +1775,7 @@ void KolfGame::openFile()
 	}
 
 	m_moveableQItems = m_topLevelQItems = newTopLevelQItems;
-	selectedItem = 0;
+	selectedItem = nullptr;
 
 	// will tell basic course info
 	// we do this here for the hell of it.
@@ -1790,7 +1785,7 @@ void KolfGame::openFile()
 	holeInfo.setAuthor(cfgGroup.readEntry("author", holeInfo.author()));
 	holeInfo.setName(cfgGroup.readEntry("Name", holeInfo.name()));
 	holeInfo.setUntranslatedName(cfgGroup.readEntryUntranslated("Name", holeInfo.untranslatedName()));
-	emit titleChanged(holeInfo.name());
+	Q_EMIT titleChanged(holeInfo.name());
 
 	cfgGroup = KConfigGroup(KSharedConfig::openConfig(filename), QStringLiteral("%1-hole@-50,-50|0").arg(curHole));
 	curPar = cfgGroup.readEntry("par", 3);
@@ -1889,7 +1884,7 @@ void KolfGame::openFile()
 		// we're done, let's quit
 		curHole--;
 		pause();
-		emit holesDone();
+		Q_EMIT holesDone();
 
 		// tidy things up
 		setBorderWalls(false);
@@ -1914,7 +1909,7 @@ void KolfGame::openFile()
 	{
 		highestHole = _highestHole;
 		recalcHighestHole = false;
-		emit largestHole(highestHole);
+		Q_EMIT largestHole(highestHole);
 	}
 
 	if (curHole == 1 && !filename.isNull() && !infoShown)
@@ -1948,8 +1943,7 @@ void KolfGame::addNewObject(const QString& identifier)
 	for (;; ++i)
 	{
 		bool found = false;
-		foreach (QGraphicsItem* qitem, m_topLevelQItems)
-		{
+		for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
 			CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 			if (citem)
 			{
@@ -1969,7 +1963,8 @@ void KolfGame::addNewObject(const QString& identifier)
 
 	sceneItem->setGame(this);
 
-	foreach (QGraphicsItem* qitem, sceneItem->infoItems())
+	const auto infoItems = sceneItem->infoItems();
+	for (QGraphicsItem* qitem : infoItems)
 		qitem->setVisible(m_showInfo);
 
 	sceneItem->editModeChanged(editing);
@@ -1990,7 +1985,7 @@ bool KolfGame::askSave(bool noMoreChances)
 		// not cancel, don't save
 		return false;
 
-	int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to current hole. Save them?"), i18n("Unsaved Changes"), KStandardGuiItem::save(), noMoreChances? KStandardGuiItem::discard() : KGuiItem(i18n("Save &Later")), KStandardGuiItem::cancel(), noMoreChances? "DiscardAsk" : "SaveAsk");
+	int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to current hole. Save them?"), i18n("Unsaved Changes"), KStandardGuiItem::save(), noMoreChances? KStandardGuiItem::discard() : KGuiItem(i18n("Save &Later")), KStandardGuiItem::cancel(), noMoreChances? QStringLiteral("DiscardAsk") : QStringLiteral("SaveAsk"));
 	switch (result)
 	{
 		case KMessageBox::Yes:
@@ -2030,7 +2025,7 @@ void KolfGame::addNewHole()
 	recalcHighestHole = true;
 	startNextHole();
 	addingNewHole = false;
-	emit currentHole(curHole);
+	Q_EMIT currentHole(curHole);
 
 	// make sure even the current player isn't showing
 	for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
@@ -2041,7 +2036,8 @@ void KolfGame::addNewHole()
 	inPlay = false;
 
 	// add default objects
-	foreach (const Kolf::ItemMetadata& metadata, m_factory.knownTypes())
+	const auto knownTypes = m_factory.knownTypes();
+	for (const Kolf::ItemMetadata& metadata : knownTypes)
 		if (metadata.addOnNewHole)
 			addNewObject(metadata.identifier);
 
@@ -2064,15 +2060,15 @@ void KolfGame::resetHoleScores()
 	for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
 	{
 		(*it).resetScore(curHole);
-		emit scoreChanged((*it).id(), curHole, 0);
+		Q_EMIT scoreChanged((*it).id(), curHole, 0);
 	}
 }
 
 void KolfGame::clearHole()
 {
 	QList<QGraphicsItem*> newTopLevelQItems;
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	const auto currentTopLevelQItems = m_topLevelQItems;
+	for (QGraphicsItem* qitem : currentTopLevelQItems) {
 		if (dynamic_cast<Ball*>(qitem))
 		{
 			//do not delete balls
@@ -2087,10 +2083,11 @@ void KolfGame::clearHole()
 	}
 
 	m_moveableQItems = m_topLevelQItems = newTopLevelQItems;
-	setSelectedItem(0);
+	setSelectedItem(nullptr);
 
 	// add default objects
-	foreach (const Kolf::ItemMetadata& metadata, m_factory.knownTypes())
+	const auto knownTypes = m_factory.knownTypes();
+	for (const Kolf::ItemMetadata& metadata : knownTypes)
 		if (metadata.addOnNewHole)
 			addNewObject(metadata.identifier);
 
@@ -2174,8 +2171,8 @@ void KolfGame::save()
 		delete fileSaveDialog;
 	}
 
-	emit parChanged(curHole, holeInfo.par());
-	emit titleChanged(holeInfo.name());
+	Q_EMIT parChanged(curHole, holeInfo.par());
+	Q_EMIT titleChanged(holeInfo.name());
 
 	const QStringList groups = cfg->groupList();
 
@@ -2186,8 +2183,7 @@ void KolfGame::save()
 		if (holeNum == curHole)
 			cfg->deleteGroup(*it);
 	}
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 		{
@@ -2225,30 +2221,29 @@ void KolfGame::toggleEditMode()
 	   {
 	   if (askSave(false))
 	   {
-	   emit checkEditing();
+	   Q_EMIT checkEditing();
 	   return;
 	   }
 	   }
 	   */
 
-	selectedItem = 0;
+	selectedItem = nullptr;
 
 	editing = !editing;
 
 	if (editing)
 	{
-		emit editingStarted();
-		setSelectedItem(0);
+		Q_EMIT editingStarted();
+		setSelectedItem(nullptr);
 	}
 	else
 	{
-		emit editingEnded();
+		Q_EMIT editingEnded();
 		setCursor(Qt::ArrowCursor);
 	}
 
 	// alert our items
-	foreach (QGraphicsItem* qitem, m_topLevelQItems)
-	{
+	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(qitem)) continue;
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
@@ -2282,10 +2277,9 @@ void KolfGame::setSelectedItem(CanvasItem* citem)
 {
 	QGraphicsItem* qitem = dynamic_cast<QGraphicsItem*>(citem);
 	selectedItem = qitem;
-	emit newSelectedItem(qitem ? citem : &holeInfo);
+	Q_EMIT newSelectedItem(qitem ? citem : &holeInfo);
 	//deactivate all other overlays
-	foreach (QGraphicsItem* otherQitem, m_topLevelQItems)
-	{
+	for (QGraphicsItem* otherQitem : qAsConst(m_topLevelQItems)) {
 		CanvasItem* otherCitem = dynamic_cast<CanvasItem*>(otherQitem);
 		if (otherCitem && otherCitem != citem)
 		{
@@ -2314,7 +2308,7 @@ bool KolfGame::allPlayersDone()
 
 void KolfGame::setBorderWalls(bool showing)
 {
-	foreach (Kolf::Wall* wall, borderWalls)
+	for (Kolf::Wall* wall : qAsConst(borderWalls))
 		wall->setVisible(showing);
 }
 
